@@ -1,6 +1,6 @@
 require File.dirname(__FILE__) + '/../../test_helper'
 
-class Gateway < Test::Unit::TestCase
+class GatewayTest < Test::Unit::TestCase
   def test_should_detect_if_a_card_is_supported
     Gateway.supported_cardtypes = [:visa, :bogus]
     assert [:visa, :bogus].all? { |supported_cardtype| Gateway.supports?(supported_cardtype) }
@@ -38,4 +38,11 @@ class Gateway < Test::Unit::TestCase
     credit_card = stub(:type => "String", :brand => "visa")
     assert_equal "visa", Gateway.card_brand(credit_card)
   end
+  
+  def test_setting_application_id_outside_the_class_definition
+    assert_equal SimpleTestGateway.application_id, SubclassGateway.application_id
+    SimpleTestGateway.application_id = "New Application ID"
+    
+    assert_equal SimpleTestGateway.application_id, SubclassGateway.application_id
+  end
 end
\ No newline at end of file
